"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tsyringe_1 = require("tsyringe");
const express_1 = __importDefault(require("express"));
const http_status_codes_1 = require("http-status-codes");
const basic_auth_1 = require("../middleware/basic-auth");
const capacityProvider = tsyringe_1.container.resolve('FillarivahtiHslCapacityProvider.CapacityProvider');
const capacityRepository = tsyringe_1.container.resolve('FillarivahtiCapacityRepository.CapacityRepository');
const logger = tsyringe_1.container.resolve('FillarivahtiRecorderHttpApi.Logger');
// eslint-disable-next-line new-cap
const recordRouter = express_1.default.Router();
recordRouter.use(basic_auth_1.middleware);
recordRouter.post('/', async (req, res) => {
    logger.info('Fillarivahti recorder recording is run.');
    try {
        const capacities = await capacityProvider.getCapacities();
        await capacityRepository.createMany(capacities);
        logger.info('Fillarivahti recorder recording is completed.');
        return res.status(http_status_codes_1.StatusCodes.OK).end();
    }
    catch (error) {
        logger.error('Failed to record bike station capacities.', {
            error: error.message,
            stack: error.stack,
        });
        return res.status(http_status_codes_1.StatusCodes.INTERNAL_SERVER_ERROR).end();
    }
});
exports.default = recordRouter;
