"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tsyringe_1 = require("tsyringe");
const express_1 = __importDefault(require("express"));
const http_status_codes_1 = require("http-status-codes");
const basic_auth_1 = require("../middleware/basic-auth");
const capacityShredder = tsyringe_1.container.resolve('FillarivahtiCapacityRepository.CapacityShredder');
const logger = tsyringe_1.container.resolve('FillarivahtiRecorderHttpApi.Logger');
// eslint-disable-next-line new-cap
const shredRouter = express_1.default.Router();
shredRouter.use(basic_auth_1.middleware);
shredRouter.post('/', async (req, res) => {
    logger.info('Fillarivahti recorder shredding is run.');
    // TODO: move to configuration
    // Capacity records are retained for 5 full weeks (5 * 7 = 35), ie. the
    // current week and 4 weeks prior.
    const olderThanDays = 35;
    try {
        await capacityShredder.shredByAge(olderThanDays);
        logger.info('Fillarivahti recorder shredding is completed.');
        return res.status(http_status_codes_1.StatusCodes.OK).end();
    }
    catch (error) {
        logger.error('Failed to shred old bike station capacities.', {
            error: error.message,
            stack: error.stack,
        });
        return res.status(http_status_codes_1.StatusCodes.INTERNAL_SERVER_ERROR).end();
    }
});
exports.default = shredRouter;
